@@ -1,7 +1,14 @@
 import os
+import sys
+import warnings
 
+if sys.version_info < (3, 5):
+    warnings.warn(
+        "Support for your Python version is deprecated and will be removed in the future",
+        DeprecationWarning,
+    )
 
-version_info = (0, 29, 1)
+version_info = (0, 31, 0)
 __version__ = '.'.join(map(str, version_info))
 # This is to make Debian packaging easier, it ignores import
 # errors of greenlet so that the packager can still at least
